"""
This type stub file was generated by pyright.
"""

"""A module for creating docstrings for sphinx ``data`` domains."""
_docstrings_list = ...
def add_newdoc(name: str, value: str, doc: str) -> None:
    """Append ``_docstrings_list`` with a docstring for `name`.

    Parameters
    ----------
    name : str
        The name of the object.
    value : str
        A string-representation of the object.
    doc : str
        The docstring of the object.

    """
    ...

_docstrings = ...
